Index: Daodan/src/Daodan.c
===================================================================
--- Daodan/src/Daodan.c	(revision 705)
+++ Daodan/src/Daodan.c	(revision 739)
@@ -216,5 +216,5 @@
 	if (patch_newweapon) {
 		
-		//Makes it always say "Recieved weapon_name."
+		//Makes it always say "Received weapon_name."
 		//Needs check for loc_4DFC66
 		//DDrPatch_NOOP((char*)(OniExe + 0x000E4DF8),2);
@@ -602,5 +602,5 @@
 {
 	if (opt_usedaodanbsl)
-		SLrDaodan_Initalize();
+		SLrDaodan_Initialize();
 }
 
Index: Daodan/src/Daodan_BSL.c
===================================================================
--- Daodan/src/Daodan_BSL.c	(revision 705)
+++ Daodan/src/Daodan_BSL.c	(revision 739)
@@ -442,5 +442,5 @@
 	{"F7", Action_F7                        },
 	{"F8", Action_F8                        },
-	{"StartRecorn", Action_StartRecord        },       
+	{"StartRecord", Action_StartRecord        },       
 	{"StopRecord", Action_StopRecord            },    
 	{"PlayRecord", Action_PlayRecord              },  
@@ -890,5 +890,5 @@
 }
 
-void SLrDaodan_Initalize()
+void SLrDaodan_Initialize()
 {
  	SLrConfig();
@@ -924,6 +924,6 @@
 
 	SLrScript_Command_Register_Void("sprintf", "C-style sprintf.", "", bsl_sprintf);
-	SLrScript_Command_Register_ReturnType("st", "prints to console in color", "", sl_void, bsl_dprintcolored);
-	SLrScript_Command_Register_ReturnType("d_dprint", "prints to console in color", "", sl_void, bsl_dprintcolored);
+	SLrScript_Command_Register_ReturnType("st", "Prints to console in color", "", sl_void, bsl_dprintcolored);
+	SLrScript_Command_Register_ReturnType("d_dprint", "Prints to console in color", "", sl_void, bsl_dprintcolored);
 }
 
Index: Daodan/src/Daodan_BSL.h
===================================================================
--- Daodan/src/Daodan_BSL.h	(revision 705)
+++ Daodan/src/Daodan_BSL.h	(revision 739)
@@ -2,5 +2,5 @@
 #define DAODAN_BSL_H
 
-void SLrDaodan_Initalize();
+void SLrDaodan_Initialize();
 void SLrDaodan_Patch();
 
Index: Daodan/src/Daodan_Character.c
===================================================================
--- Daodan/src/Daodan_Character.c	(revision 705)
+++ Daodan/src/Daodan_Character.c	(revision 739)
@@ -11,5 +11,5 @@
 	else if (!strcmp(team_string, "Neutral"))            return team_neutral;
 	else if (!strcmp(team_string, "SecurityGuard"))      return team_securityguard;
-	else if (!strcmp(team_string, "RougeKonoko"))        return team_rougekonoko;
+	else if (!strcmp(team_string, "RogueKonoko"))        return team_roguekonoko;
 	else if (!strcmp(team_string, "Switzerland"))        return team_switzerland;
 	else if (!strcmp(team_string, "SyndicateAccessory")) return team_syndicateaccessory;
Index: Daodan/src/Daodan_GL.c
===================================================================
--- Daodan/src/Daodan_GL.c	(revision 705)
+++ Daodan/src/Daodan_GL.c	(revision 739)
@@ -104,5 +104,5 @@
 	else
 	{
-		// In -noswtich we put predefined window sizes which don't overlap
+		// In -noswitch we put predefined window sizes which don't overlap
 		// deskbar(s) plus one "native" fullscreen mode.
 
@@ -399,5 +399,5 @@
 	if (!M3gResolutionSwitch && opt_gamma)
 	{
-		UUrStartupMessage("Ignoring gamma setting for a windowed mode");
+		UUrStartupMessage("Ignoring gamma setting due to windowed mode");
 		opt_gamma = false;
 	}
Index: Daodan/src/Oni_GL.h
===================================================================
--- Daodan/src/Oni_GL.h	(revision 705)
+++ Daodan/src/Oni_GL.h	(revision 739)
@@ -22,5 +22,5 @@
 	int e;
 	int Color;
-	int MaxTetxureSize;
+	int MaxTextureSize;
 	int DoubleBufferSupported;
 	int MaxTextureUnits;
Index: Daodan/src/Oni_GameState.h
===================================================================
--- Daodan/src/Oni_GameState.h	(revision 705)
+++ Daodan/src/Oni_GameState.h	(revision 739)
@@ -1201,5 +1201,5 @@
   __int16 field_1C9A;
   int field_1C9C;
-  __int16 AnimationVarient;
+  __int16 AnimationVariant;
   __int16 TimeToPeace;
   char NumAnimationAttachedParticles;

Index: Daodan/src/Oni_Character.h
===================================================================
--- Daodan/src/Oni_Character.h	(revision 705)
+++ Daodan/src/Oni_Character.h	(revision 739)
@@ -10,5 +10,5 @@
 	team_neutral,
 	team_securityguard,
-	team_rougekonoko,
+	team_roguekonoko,
 	team_switzerland,
 	team_syndicateaccessory,
@@ -36,9 +36,9 @@
 		
 	ONcCharacterFlag_BeingThrown			=	0x00001000,	// this character is being thrown
-	ONcCharacterFlag_DontUseGunVarient		=	0x00002000,	// this character should not use a weapon varient
+	ONcCharacterFlag_DontUseGunVariant		=	0x00002000,	// this character should not use a weapon variant
 	ONcCharacterFlag_Draw					=	0x00004000,	// DoFrame has been executed for this character
 	ONcCharacterFlag_InUse					=	0x00008000,	// this character is active and in use
 
-	ONcCharacterFlag_DontUseFightVarient	=	0x00010000,
+	ONcCharacterFlag_DontUseFightVariant	=	0x00010000,
 	ONcCharacterFlag_NoCollision			=	0x00020000,	// no collision for this character
 	ONcCharacterFlag_Teleporting			=	0x00040000,	// this character is teleporting and does not accept collision
@@ -48,5 +48,5 @@
 	ONcCharacterFlag_ChrAnimate				=	0x00200000,	// the character is currently runing a chr_animate command
 	ONcCharacterFlag_AIMovement				=	0x00400000,	// the character is using AI movement
-	ONcCharacterFlag_NeutralUninterruptable	=	0x00800000,	// running an uninterruptable neutral interaction
+	ONcCharacterFlag_NeutralUninterruptible	=	0x00800000,	// running an uninterruptible neutral interaction
 
 	ONcCharacterFlag_NoShadow				=	0x01000000,	// 